Struct rustc_trans::middle::mem_categorization::UpvarUnstable
[-] [+]
[src]
pub struct Upvar {
pub id: UpvarId,
pub kind: ClosureKind,
}Fields
id | |
kind |
pub struct Upvar {
pub id: UpvarId,
pub kind: ClosureKind,
}id | |
kind |
impl<'tcx> Repr<'tcx> for Upvarimpl<'tcx> UserString<'tcx> for Upvarfn user_string(&self, &ctxt) -> Stringimpl Debug for Upvarimpl PartialEq<Upvar> for Upvarimpl Copy for Upvarimpl Clone for Upvarfn clone(&self) -> Upvarfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).